@@ -7,7 +7,7 @@ class HltVisitHistory(BaseModel):
     """
 
     id = models.AutoField(db_column="VisitHistoryID", primary_key=True)
-    uuid = models.CharField(db_column="GUID", max_length=36, unique=True, default=uuid.uuid4)
+    uuid = models.CharField(db_column="GUID", max_length=36, unique=True, default=uuid4)
     date = models.DateTimeField(db_column="Date")
     is_complete = models.BooleanField(db_column="IsComplete")
     doctor_visit_table = models.ForeignKey("HltDoctorVisitTable", db_column="rf_DoctorVisitTableID", **FK_DEFAULT)
